#!/bin/bash

# Zenwalk Gnu/Linux build script written for "E17_LIBS: (EFL, The Enlightenment Foundation Libraries)"
# Soft Home Page: http://www.enlightenment.org
# Source URL: Enlightenment CVS
# Package Contents: ecore, edb, edje, eet, efreet, embryo, emotion, engrave, enhance, epeg, epsilon, esmart, etk, etox, evas, ewl, exml & imlib2_loaders																																																																																																																																																																																																																																																															"
# Software's Dependencies: "avahi,bzip2,curl,cxxlibs,dbus,dbus-glib,expat,fontconfig,freetype,gcc,gconf,glib2,gnome-vfs,gstreamer,gtk+2,imlib2,libcroco,libdrm,libgsf,libidn,libjpeg,libpng,librsvg,libtiff,libtool,libungif,libxml2,libxslt,mesa,ncurses,openssl,orbit2,pango,xine-lib,xorg,zlib"
# Package Maintainer: Michael Verret (AxXium) axxium.zenlnx@gmail.com
# Date of script Revision: Thursday 28 June 2007


#------------------( Unique Package Variables )


SOFT='e17_libs'
SOFTVERSION='0.9.9.039'		# Obtain the version from the file configure.in of the evas source package
SOURCEDATE='CVS20070628'
BUILDVERSION='48.3'
ARCH='i686'
CPU='i686'
KEY='ZEN'
DOCS="AUTHORS COPYING* ChangeLog INSTALL README TODO"
HELPERS="ECORE EDB EDJE EET EFREET EMBRYO EMOTION ENGRAVE \
  ENHANCE EPEG EPSILON ESMART ETK EVAS EWL EXML IMLIB2LOADERS"


#------------------( Actual Software Versions )


# Found in the file "configure.in" of each source package

ECOREVERSION='0.9.9.039'
EDBVERSION='1.0.5.007'
EDJEVERSION='0.5.0.039'
EETVERSION='0.9.10.039'
EFREETVERSION='0.0.3.004'
EMBRYOVERSION='0.9.1.039'
EMOTIONVERSION='0.0.1.006'
ENGRAVEVERSION='0.1.0'
ENHANCEVERSION='0.0.1'
EPEGVERSION='0.9.0.009'
EPSILONVERSION='0.3.0.009'
ESMARTVERSION='0.9.0.009'
ETKVERSION='0.1.0.004'
EVASVERSION='0.9.9.039'
EWLVERSION='0.5.1.009'
EXMLVERSION='0.1.1'
IMLIB2LOADERSVERSION='1.4.0.001'


#------------------( Source Packages )


SOURCES=" \
ecore-$SOURCEDATE.tar.bz2 /
edb-$SOURCEDATE.tar.bz2 /
edje-$SOURCEDATE.tar.bz2 /
eet-$SOURCEDATE.tar.bz2 /
efreet-$SOURCEDATE.tar.bz2 /
embryo-$SOURCEDATE.tar.bz2 /
emotion-$SOURCEDATE.tar.bz2 /
engrave-$SOURCEDATE.tar.bz2 /
enhance-$SOURCEDATE.tar.bz2 /
epeg-$SOURCEDATE.tar.bz2 /
epsilon-$SOURCEDATE.tar.bz2 /
esmart-$SOURCEDATE.tar.bz2 /
etk-$SOURCEDATE.tar.bz2 /
evas-$SOURCEDATE.tar.bz2 /
ewl-$SOURCEDATE.tar.bz2 /
exml-$SOURCEDATE.tar.bz2 /
imlib2_loaders-$SOURCEDATE.tar.bz2 "


#------------------( Standard Variables & Routines )


REACTOR="$SOFT-$SOFTVERSION"
BUILDIR=$(pwd)
cd $BUILDIR
PACKAGE="$REACTOR-$ARCH-$BUILDVERSION"
DEST="$BUILDIR/$PACKAGE"

rm -rf {$DEST,$DEST.dep,$DEST.md5,$DEST.tgz,$PACKAGE,$PACKAGE.dep,$PACKAGE.md5,SANDBOX} 1>/dev/null 2>&1
mkdir -p SANDBOX
mkdir -p $DEST


#------------------( Check To See If We Are Missing Any Toys )


for file in $SOURCES ; do
  echo -n "$file :"
  if [ -e $file ]; then
    echo " OK"
  else
    echo " missing !"
    exit 1
  fi
done


#------------------( Build Eet )


( src='eet'
  SRCDIR="eet-$SOURCEDATE"
  PKGVERSION="$EETVERSION"
  KEY='EET'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-compat185 \
  --enable-dump185 \
  --enable-gtk \
  --enable-ncurses
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Evas )


( src='evas'
  SRCDIR="evas-$SOURCEDATE"
  PKGVERSION="$EVASVERSION"
  KEY='EVAS'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-cpu-p2-only \
  --enable-scale-sample \
  --enable-scale-smooth \
  --enable-scale-trilinear \
  --enable-cairo \
  --enable-cairo-x11 \
  --enable-glitz-x11 \
  --enable-X \
  --enable-software-x11 \
  --enable-opengl \
  --enable-gl-x11 \
  --enable-fbcon \
  --enable-fb \
  --enable-image-loader-eet \
  --enable-image-loader-edb \
  --enable-fmemopen \
  --enable-cpu-c \
  --enable-scale-smooth \
  --enable-scale-sample \
  --enable-convert-8-rgb-332 \
  --enable-convert-8-rgb-666 \
  --enable-convert-8-rgb-232 \
  --enable-convert-8-rgb-222 \
  --enable-convert-8-rgb-221 \
  --enable-convert-8-rgb-111 \
  --enable-convert-16-rgb-565 \
  --enable-convert-16-rgb-555 \
  --enable-convert-16-rgb-444 \
  --enable-convert-16-rgb-rot-0 \
  --enable-convert-16-rgb-rot-270 \
  --enable-convert-16-rgb-rot-90 \
  --enable-convert-24-rgb-888 \
  --enable-convert-24-bgr-888 \
  --enable-convert-32-rgb-8888 \
  --enable-convert-32-rgbx-8888 \
  --enable-convert-32-bgr-8888 \
  --enable-convert-32-bgrx-8888 \
  --enable-convert-32-rgb-rot-0 \
  --enable-convert-32-rgb-rot-270 \
  --enable-convert-32-rgb-rot-90 \
  --enable-png \
  --enable-image-loader-png \
  --enable-jpeg \
  --enable-image-loader-jpeg \
  --disable-mmx \
  --disable-cpu-mmx \
  --disable-sse \
  --disable-cpu-sse
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Ecore )


( src='ecore'
  SRCDIR="ecore-$SOURCEDATE"
  PKGVERSION="$ECOREVERSION"
  KEY='ECORE'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-ecore-txt \
  --enable-X \
  --enable-ecore-x \
  --enable-ecore-job \
  --enable-fbcon \
  --enable-ecore-fb \
  --enable-ecore-evas \
  --enable-opengl \
  --enable-ecore-evas-gl \
  --enable-X \
  --enable-evas-xrender \
  --enable-fbcon \
  --enable-ecore-evas-buffer \
  --enable-ecore-con \
  --enable-ssl \
  --enable-openssl \
  --enable-ecore-ipc \
  --enable-dbus \
  --enable-ecore-dbus \
  --enable-ecore-config \
  --enable-ecore-file \
  --enable-curl \
  --enable-threads \
  --enable-pthreads
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Edb )


( src='edb'
  SRCDIR="edb-$SOURCEDATE"
  PKGVERSION="$EDBVERSION"
  KEY='EDB'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-compat185 \
  --enable-dump185 \
  --enable-gtk \
  --enable-ncurses
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Embryo )


( src='embryo'
  SRCDIR="embryo-$SOURCEDATE"
  PKGVERSION="$EMBRYOVERSION"
  KEY='EMBRYO'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Edje )


( src='edje'
  SRCDIR="edje-$SOURCEDATE"
  PKGVERSION="$EDJEVERSION"
  KEY='EDJE'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Efreet )


( src='efreet'
  SRCDIR="efreet-$SOURCEDATE"
  PKGVERSION="$EFREETVERSION"
  KEY='EFREET'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Emotion )


( src='emotion'
  SRCDIR="emotion-$SOURCEDATE"
  PKGVERSION="$EMOTIONVERSION"
  KEY='EMOTION'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-xine \
  --enable-gstreamer
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Epeg )


( src='epeg'
  SRCDIR="epeg-$SOURCEDATE"
  PKGVERSION="$EPEGVERSION"
  KEY='EPEG'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Epsilon )


( src='epsilon'
  SRCDIR="epsilon-$SOURCEDATE"
  PKGVERSION="$EPSILONVERSION"
  KEY='EPSILON'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Etk )


( src='etk'
  SRCDIR="etk-$SOURCEDATE"
  PKGVERSION="$ETKVERSION"
  KEY='ETK'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Exml )


( src='exml'
  SRCDIR="exml-$SOURCEDATE"
  PKGVERSION="$EXMLVERSION"
  KEY='EXML'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Engrave )


( src='engrave'
  SRCDIR="engrave-$SOURCEDATE"
  PKGVERSION="$ENGRAVEVERSION"
  KEY='ENGRAVE'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Enhance )


( src='enhance'
  SRCDIR="enhance-$SOURCEDATE"
  PKGVERSION="$ENHANCEVERSION"
  KEY='ENHANCE'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Esmart )


( src='esmart'
  SRCDIR="esmart-$SOURCEDATE"
  PKGVERSION="$ESMARTVERSION"
  KEY='ESMART'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Ewl )


( src='ewl'
  SRCDIR="ewl-$SOURCEDATE"
  PKGVERSION="$EWLVERSION"
  KEY='EWL'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --enable-software-x11 \
  --enable-xrender-x11 \
  --enable-opengl-x11
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Build Imlib2_loaders )


( src='imlib2_loaders'
  SRCDIR="imlib2_loaders-$SOURCEDATE"
  PKGVERSION="$IMLIB2LOADERSVERSION"
  KEY='IMLIB2LOADERS'
#------------------/
    cd $BUILDIR/SANDBOX
      tar -xvjf ../$SRCDIR.tar.bz2
      cd $SRCDIR
        export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
        export CXXFLAGS="$CFLAGS"
          ./autogen.sh --prefix=/usr
./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --docdir=/usr/doc/$SOURCENAME-$SOURCEVERSION \
  --htmldir=/usr/doc/$SOURCENAME-$SOURCEVERSION/html \
  --dvidir=/usr/doc/$SOURCENAME-$SOURCEVERSION/dvi \
  --pdfdir=/usr/doc/$SOURCENAME-$SOURCEVERSION/pdf \
  --psdir=/usr/doc/$SOURCENAME-$SOURCEVERSION/ps \
  --enable-eet \
  --enable-edb \
  --enable-xcf
            make -j4
            mkdir -p $DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST/../SANDBOX/$KEY
            make install DESTDIR=$DEST
          mkdir -p $DEST/usr/doc/$src-$PKGVERSION
          cp $DOCS $DEST/usr/doc/$src-$PKGVERSION
        cd $DEST/../SANDBOX/$KEY
        makepkg -l y -c n ../$KEY.tgz
      cd ../
      installpkg $KEY.tgz
  rm -rf {$SRCDIR,$KEY}
)


#------------------( Remove The Stuff We Installed )


removepkg $HELPERS.tgz


#------------------( Delete Empty Documentation Files )


( cd $DEST/usr/doc
  find ./*/ -empty -delete
)


#------------------( Package Prep )


( cd $DEST
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $DEST/install
cat <<EOF > $DEST/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
$SOFT: Enlightenment Foundation Libraries for Enlightenment DR 0.17
$SOFT: 
$SOFT: The EFL contains solutions for almost any graphical interface
$SOFT: task, far beyond just rendering images. Combined they form an
$SOFT: entirely new set of libraries and tools created for E17.
$SOFT: Originaly starting with Imlib2 and EVAS, the EFL has expanded
$SOFT: and now contains ecore, edb, edje, eet, efreet, embryo, emotion,																																																																																																																																																																																																																																																															"
$SOFT: engrave, enhance, epeg, epsilon, esmart, etk, etox, evas, ewl,
$SOFT: exml, imlib2 & imlib2_loaders. This package contains all of
$SOFT: above EFL with exception to Imlib2, which is packaged seperately
$SOFT: since it is also required by some Non-E17 applications.
EOF

mkdir -p $DEST/usr/src/$REACTOR
cp $BUILDIR/build-$SOFT.sh $DEST/usr/src/$REACTOR/build-$SOFT.sh


#------------------( Packaging )


cd $DEST
requiredbuilder -z $DEST >> $BUILDIR/$PACKAGE.dep

makepkg -l y -c n ../$PACKAGE.tgz
cd $BUILDIR
rm -rf {$DEST,$REACTOR,SANDBOX} 1>/dev/null 2>&1

md5sum $PACKAGE.tgz > $PACKAGE.md5